@@ -1,6 +1,6 @@
 import click
 
-from .logic import run_clone, run_submit
+from .logic import run_clone, run_submit, run_instance
 
 @click.group()
 def cli():
