@@ -1,18 +1,18 @@
 from .abc import APIBaseObject
-from .helpers.requests import post
+from .helpers.requests import post, get
 from .hint import Hint
 from .file import File
+from .errors import APIError
 
 
 class Challenge(APIBaseObject):
     def __init__(self, object_id, ctf, data=None):
         self.id = object_id
-        self.unlocked = False
         self.ctf = ctf
+        self.challenge_metadata = {}
         super(Challenge, self).__init__(ctf, data=data)
-        if self.unlocked:
-            self.convert_json_to_hints()
-            self.convert_json_to_files()
+        self.convert_json_to_hints()
+        self.convert_json_to_files()
 
     def get_api_path(self):
         return f"challenges/{self.id}/"
@@ -37,4 +37,10 @@ class Challenge(APIBaseObject):
         resp = post("challenges/submit_flag/", self.ctf, json={"challenge": self.id, "flag": flag})
         # again, bug
         # self._fill_attrs()
-        return resp["m"] == "correct_flag"
\ No newline at end of file
+        return resp["m"] == "correct_flag"
+
+    def get_challenge_server_instance(self):
+        if not self.challenge_metadata.get('cserv_name'):
+            raise APIError("Challenge has no instance attached")
+        d = get(f"challengeserver/instance/{self.challenge_metadata.get('cserv_instance')}/", self.ctf)
+        return f"{d['ip']}:{d['port']}"
\ No newline at end of file
